@@ -73,7 +73,7 @@ class StorageService(OSSMixin):
             file_path: 本地文件路径
             project_id: 项目 ID
             analysis_node: 分析节点名称
-            file_category: 文件分类（如 'results', 'plot_data'）
+            file_category: 文件分类（如 'results', 'plot_data'）。若不指定且文件名以'report'开头的HTML文件会自动设为'report'
             key: 自定义 OSS 键名，不提供则自动生成
             sample_id: 样本 ID（可选）
             description: 文件描述（可选）
@@ -99,6 +99,12 @@ class StorageService(OSSMixin):
         if not file_path.exists():
             raise FileNotFoundError(f"文件不存在: {file_path}")
 
+        # 智能检测 HTML 报告文件
+        if file_category is None:
+            filename_lower = file_path.name.lower()
+            if filename_lower.startswith("report") and filename_lower.endswith(".html"):
+                file_category = "report"
+
         # 构建 OSS 键名：biofile/{env}/project_id/[base_path/]filename
         if not key:
             # 如果没有指定 base_path，对单文件上传使用 analysis_node/sample_id 作为默认路径
@@ -247,14 +253,14 @@ class StorageService(OSSMixin):
         try:
             # 检查文件是否存在并获取文件信息
             try:
-                obj_info = bucket.get_object_meta(oss_key)
+                obj_info = self._get_object_meta_with_retry(bucket, oss_key)
                 file_size = obj_info.content_length
             except oss2.exceptions.NoSuchKey:
                 raise FileNotFoundError(f"OSS 文件不存在: {oss_key}")
 
             # 直接下载文件
-            bucket.get_object_to_file(
-                oss_key, str(local_path), progress_callback=progress_callback
+            self._get_object_to_file_with_retry(
+                bucket, oss_key, str(local_path), progress_callback=progress_callback
             )
 
             # 验证下载完成
@@ -285,7 +291,7 @@ class StorageService(OSSMixin):
         """检查文件是否存在"""
         try:
             bucket = self._get_oss_bucket(project_id)
-            return bucket.object_exists(oss_key)
+            return self._object_exists_with_retry(bucket, oss_key)
         except Exception:
             return False
 
@@ -294,7 +300,7 @@ class StorageService(OSSMixin):
         bucket = self._get_oss_bucket(project_id)
 
         try:
-            obj_info = bucket.get_object_meta(oss_key)
+            obj_info = self._get_object_meta_with_retry(bucket, oss_key)
             if obj_info is None:
                 raise APIError(f"无法获取文件元数据: {oss_key}")
 
