@@ -6,7 +6,6 @@ import re
 from decimal import ROUND_HALF_UP, Decimal
 from pathlib import Path
 from typing import Any, Union
-from urllib.parse import urlparse
 
 import orjson
 import requests
@@ -119,31 +118,6 @@ def format_file_size(size_bytes: int) -> str:
     return f"{size_bytes:.1f} PB"
 
 
-def is_json_content(content: Union[str, bytes, dict]) -> bool:
-    """判断内容是否为 JSON 格式
-
-    Args:
-        content: 要检查的内容
-
-    Returns:
-        是否为 JSON 格式
-    """
-    if isinstance(content, dict):
-        return True
-
-    if isinstance(content, bytes):
-        content = content.decode("utf-8", errors="ignore")
-
-    if isinstance(content, str):
-        try:
-            orjson.loads(content)
-            return True
-        except (orjson.JSONDecodeError, ValueError):
-            return False
-
-    return False
-
-
 def handle_api_response(
     response: requests.Response, operation: str = "API调用"
 ) -> dict[str, Any]:
@@ -229,19 +203,6 @@ def get_json_size(data: Any) -> int:
     return len(json_str.encode("utf-8"))
 
 
-def get_hostname_from_url(url: str) -> str:
-    """从URL中提取主机名
-
-    Args:
-        url: URL地址
-
-    Returns:
-        主机名字符串
-    """
-    parsed = urlparse(url)
-    return parsed.hostname or ""
-
-
 def get_temp_dir(custom_dir: str = None, purpose: str = "oss-upload") -> str:
     """获取可用的临时目录
 
@@ -282,3 +243,44 @@ def get_temp_dir(custom_dir: str = None, purpose: str = "oss-upload") -> str:
     fallback = os.path.join(tempfile.gettempdir(), f"lims2-{os.getpid()}")
     Path(fallback).mkdir(parents=True, exist_ok=True)
     return fallback
+
+
+def clean_plotly_data(data: dict) -> dict:
+    """清理Plotly数据，移除不必要的属性以减少文件大小和避免缩略图生成异常
+
+    Args:
+        data: Plotly图表数据
+
+    Returns:
+        dict: 清理后的数据
+    """
+    import copy
+
+    # 需要移除的问题属性（黑名单）
+    blacklist_attributes = {
+        # trace级别的问题属性
+        "frame",
+        "frames",
+        "animation",
+        "animationopts",
+        # layout级别的问题属性
+        "sliders",
+        "updatemenus",
+        "template",
+        "transitions",
+    }
+
+    def remove_blacklisted_attrs(obj):
+        """递归移除黑名单中的属性"""
+        if isinstance(obj, dict):
+            cleaned = {}
+            for key, value in obj.items():
+                if key not in blacklist_attributes:
+                    cleaned[key] = remove_blacklisted_attrs(value)
+            return cleaned
+        elif isinstance(obj, list):
+            return [remove_blacklisted_attrs(item) for item in obj]
+        else:
+            return obj
+
+    return remove_blacklisted_attrs(copy.deepcopy(data))
