@@ -55,6 +55,12 @@ def chart():
     default=3,
     help="浮点数精度（小数位数，0-10，默认3）",
 )
+@click.option(
+    "--retry",
+    type=click.IntRange(1, 10),
+    help="网络重试次数（1-10，默认从配置读取）",
+)
+@click.option("--timeout", type=int, help="超时时间（秒，默认从配置读取）")
 @click.pass_context
 def chart_upload(
     ctx,
@@ -67,6 +73,8 @@ def chart_upload(
     contrast,
     analysis_node,
     precision,
+    retry,
+    timeout,
 ):
     """上传图表文件
 
@@ -256,6 +264,10 @@ def storage_upload_dir(
     client = get_client(ctx)
 
     try:
+        # 进度回调函数
+        def progress_callback(current, total, filename):
+            click.echo(f"[{current}/{total}] 正在上传: {filename}")
+
         results = client.storage.upload_directory(
             dir_path,
             project_id,
@@ -264,6 +276,7 @@ def storage_upload_dir(
             sample_id=sample_id,
             recursive=True,
             base_path=base_path,
+            progress_callback=progress_callback,
         )
 
         success_count = sum(1 for r in results if not r.get("error"))
@@ -313,7 +326,7 @@ def storage_info(ctx, oss_key, project_id, output_json):
     """查看文件详细信息
 
     Examples:
-        lims2 storage info biofile/proj_001/analysis1/file.txt -p proj_001
+        lims2 storage info biofile/test/proj_001/analysis1/file.txt -p proj_001
     """
     client = get_client(ctx)
 
@@ -349,7 +362,7 @@ def storage_exists(ctx, oss_key, project_id):
     """检查文件是否存在
 
     Examples:
-        lims2 storage exists biofile/proj_001/analysis1/file.txt -p proj_001
+        lims2 storage exists biofile/test/proj_001/analysis1/file.txt -p proj_001
     """
     client = get_client(ctx)
 
